@@ -118,7 +118,7 @@ void STOP (char *s)
     S9xAPUOPrint (buffer, IAPU.PC - IAPU.RAM);
 #endif
 
-    sprintf (String, "Sound CPU in unknown state executing %s at %04lX\n%s\n", s, IAPU.PC - IAPU.RAM, buffer);
+    sprintf (String, "Sound CPU in unknown state executing %s at 0x%tx\n%s\n", s, IAPU.PC - IAPU.RAM, buffer);
     S9xMessage (S9X_ERROR, S9X_APU_STOPPED, String);
     APU.TimerEnabled[0] = APU.TimerEnabled[1] = APU.TimerEnabled[2] = FALSE;
     CPU.APU_APUExecuting = FALSE;
@@ -126,7 +126,7 @@ void STOP (char *s)
 #ifdef DEBUGGER
     CPU.Flags |= DEBUG_MODE_FLAG;
 #else
-    S9xExit ();
+    abort();
 #endif
 }
 
